@@ -9,7 +9,6 @@ from urllib.error import HTTPError
 
 import jwt
 from jupyterhub.apihandlers.base import APIHandler
-from jupyterhub.scopes import needs_scope
 from jwt.algorithms import RSAAlgorithm
 from oauthenticator.generic import GenericOAuthenticator
 from tornado import web
@@ -282,14 +281,11 @@ class AuthHandler(APIHandler):
     A custom request handler that returns user and auth state info
     """
 
-    @needs_scope("read:users")
     async def get(self):
-        user = await self.get_current_user()
+        # Similar to SelfAPIHandler
+        user = self.current_user
         if user is None:
             self.log.info('User is none')
-            # whoami can be accessed via oauth token
-            user = self.get_current_user_oauth_token()
-        if user is None:
             raise web.HTTPError(403)
 
         self.log.info('User is ' + user.name)
